package cn.com.infosec.mobile.android.xlog;

import android.support.annotation.Keep;
import cn.com.infosec.mobile.android.xlog.formatter.border.BorderFormatter;
import cn.com.infosec.mobile.android.xlog.formatter.message.json.JsonFormatter;
import cn.com.infosec.mobile.android.xlog.formatter.message.object.ObjectFormatter;
import cn.com.infosec.mobile.android.xlog.formatter.message.throwable.ThrowableFormatter;
import cn.com.infosec.mobile.android.xlog.formatter.message.xml.XmlFormatter;
import cn.com.infosec.mobile.android.xlog.formatter.stacktrace.StackTraceFormatter;
import cn.com.infosec.mobile.android.xlog.formatter.thread.ThreadFormatter;
import cn.com.infosec.mobile.android.xlog.interceptor.Interceptor;
import cn.com.infosec.mobile.android.xlog.internal.DefaultsFactory;
import cn.com.infosec.mobile.android.xlog.internal.Platform;
import cn.com.infosec.mobile.android.xlog.internal.SystemCompat;
import cn.com.infosec.mobile.android.xlog.internal.util.StackTraceUtil;
import cn.com.infosec.mobile.android.xlog.printer.Printer;
import cn.com.infosec.mobile.android.xlog.printer.PrinterSet;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

@Keep
public class Logger {
   private LogConfiguration logConfiguration;
   private Printer printer;

   Logger(LogConfiguration logConfiguration, Printer printer) {
      this.logConfiguration = logConfiguration;
      this.printer = printer;
   }

   Logger(Builder builder) {
      LogConfiguration.Builder var2;
      var2 = new LogConfiguration.Builder.<init>(XLog.sLogConfiguration);
      if (builder.logLevel != 0) {
         var2.logLevel(builder.logLevel);
      }

      if (builder.tag != null) {
         var2.tag(builder.tag);
      }

      if (builder.threadSet) {
         if (builder.withThread) {
            var2.enableThreadInfo();
         } else {
            var2.disableThreadInfo();
         }
      }

      if (builder.stackTraceSet) {
         if (builder.withStackTrace) {
            String var3 = builder.stackTraceOrigin;
            var2.enableStackTrace(var3, builder.stackTraceDepth);
         } else {
            var2.disableStackTrace();
         }
      }

      if (builder.borderSet) {
         if (builder.withBorder) {
            var2.enableBorder();
         } else {
            var2.disableBorder();
         }
      }

      if (builder.jsonFormatter != null) {
         var2.jsonFormatter(builder.jsonFormatter);
      }

      if (builder.xmlFormatter != null) {
         var2.xmlFormatter(builder.xmlFormatter);
      }

      if (builder.throwableFormatter != null) {
         var2.throwableFormatter(builder.throwableFormatter);
      }

      if (builder.threadFormatter != null) {
         var2.threadFormatter(builder.threadFormatter);
      }

      if (builder.stackTraceFormatter != null) {
         var2.stackTraceFormatter(builder.stackTraceFormatter);
      }

      if (builder.borderFormatter != null) {
         var2.borderFormatter(builder.borderFormatter);
      }

      if (builder.objectFormatters != null) {
         var2.objectFormatters(builder.objectFormatters);
      }

      if (builder.interceptors != null) {
         var2.interceptors(builder.interceptors);
      }

      this.logConfiguration = var2.build();
      if (builder.printer != null) {
         this.printer = builder.printer;
      } else {
         this.printer = XLog.sPrinter;
      }

   }

   private <T> void println(int logLevel, T object) {
      LogConfiguration var3;
      if (logLevel >= (var3 = this.logConfiguration).logLevel) {
         String object1;
         if (object != null) {
            ObjectFormatter var5;
            if ((var5 = var3.getObjectFormatter(object)) != null) {
               object1 = var5.format(object);
            } else {
               object1 = object.toString();
            }
         } else {
            object1 = "null";
         }

         this.printlnInternal(logLevel, object1);
      }
   }

   private void println(int logLevel, Object[] array) {
      if (logLevel >= this.logConfiguration.logLevel) {
         this.printlnInternal(logLevel, Arrays.deepToString(array));
      }
   }

   private void println(int logLevel, String format, Object... args) {
      if (logLevel >= this.logConfiguration.logLevel) {
         this.printlnInternal(logLevel, this.formatArgs(format, args));
      }
   }

   private void println(int logLevel, String msg, Throwable tr) {
      if (logLevel >= this.logConfiguration.logLevel) {
         StringBuilder var4;
         var4 = new StringBuilder.<init>();
         if (msg != null && msg.length() != 0) {
            msg = msg + SystemCompat.lineSeparator;
         } else {
            msg = "";
         }

         this.printlnInternal(logLevel, var4.append(msg).append(this.logConfiguration.throwableFormatter.format(tr)).toString());
      }
   }

   private void printlnInternal(int logLevel, String msg) {
      LogConfiguration var3;
      LogConfiguration var10000 = var3 = this.logConfiguration;
      String var4 = var10000.tag;
      String var9;
      if (var10000.withThread) {
         var9 = var3.threadFormatter.format(Thread.currentThread());
      } else {
         var9 = null;
      }

      LogConfiguration var5;
      String var11;
      if ((var5 = this.logConfiguration).withStackTrace) {
         StackTraceFormatter var15 = var5.stackTraceFormatter;
         StackTraceElement[] var10001 = (new Throwable()).getStackTrace();
         LogConfiguration var10002 = this.logConfiguration;
         var11 = var10002.stackTraceOrigin;
         var11 = var15.format(StackTraceUtil.getCroppedRealStackTrack(var10001, var11, var10002.stackTraceDepth));
      } else {
         var11 = null;
      }

      if (this.logConfiguration.interceptors != null) {
         LogItem var6;
         var6 = new LogItem.<init>(logLevel, var4, var9, var11, msg);
         Iterator logLevel1 = this.logConfiguration.interceptors.iterator();

         while(true) {
            if (logLevel1.hasNext()) {
               Interceptor msg1;
               if ((var6 = (msg1 = (Interceptor)logLevel1.next()).intercept(var6)) == null) {
                  return;
               }

               if (var6.tag != null && var6.msg != null) {
                  continue;
               }

               Platform.get().error("Interceptor " + msg1 + " should not remove the tag or message of a log, if you don't want to print this log, just return a null when intercept.");
               return;
            }

            logLevel = var6.level;
            var4 = var6.tag;
            var9 = var6.threadInfo;
            var11 = var6.stackTraceInfo;
            msg = var6.msg;
            break;
         }
      }

      Logger var16 = this;
      Printer var7 = this.printer;
      LogConfiguration var12;
      if ((var12 = var16.logConfiguration).withBorder) {
         msg = var12.borderFormatter.format(new String[]{var9, var11, msg});
      } else {
         StringBuilder var14;
         var14 = new StringBuilder.<init>();
         if (var9 != null) {
            var9 = var9 + SystemCompat.lineSeparator;
         } else {
            var9 = "";
         }

         StringBuilder var13 = var14.append(var9);
         if (var11 != null) {
            var11 = var11 + SystemCompat.lineSeparator;
         } else {
            var11 = "";
         }

         msg = var13.append(var11).append(msg).toString();
      }

      var7.println(logLevel, var4, msg);
   }

   private String formatArgs(String format, Object... args) {
      if (format != null) {
         return String.format(format, args);
      } else {
         StringBuilder var4;
         var4 = new StringBuilder.<init>();
         int format1 = 0;

         for(int var3 = args.length; format1 < var3; ++format1) {
            if (format1 != 0) {
               var4.append(", ");
            }

            var4.append(args[format1]);
         }

         return var4.toString();
      }
   }

   public void v(Object object) {
      this.println(2, (Object)object);
   }

   public void v(Object[] array) {
      this.println(2, (Object[])array);
   }

   public void v(String format, Object... args) {
      this.println(2, format, (Object[])args);
   }

   public void v(String msg) {
      this.println(2, (String)msg);
   }

   public void v(String msg, Throwable tr) {
      this.println(2, msg, (Throwable)tr);
   }

   public void d(Object object) {
      this.println(3, (Object)object);
   }

   public void d(Object[] array) {
      this.println(3, (Object[])array);
   }

   public void d(String format, Object... args) {
      this.println(3, format, (Object[])args);
   }

   public void d(String msg) {
      this.println(3, (String)msg);
   }

   public void d(String msg, Throwable tr) {
      this.println(3, msg, (Throwable)tr);
   }

   public void i(Object object) {
      this.println(4, (Object)object);
   }

   public void i(Object[] array) {
      this.println(4, (Object[])array);
   }

   public void i(String format, Object... args) {
      this.println(4, format, (Object[])args);
   }

   public void i(String msg) {
      this.println(4, (String)msg);
   }

   public void i(String msg, Throwable tr) {
      this.println(4, msg, (Throwable)tr);
   }

   public void w(Object object) {
      this.println(5, (Object)object);
   }

   public void w(Object[] array) {
      this.println(5, (Object[])array);
   }

   public void w(String format, Object... args) {
      this.println(5, format, (Object[])args);
   }

   public void w(String msg) {
      this.println(5, (String)msg);
   }

   public void w(String msg, Throwable tr) {
      this.println(5, msg, (Throwable)tr);
   }

   public void e(Object object) {
      this.println(6, (Object)object);
   }

   public void e(Object[] array) {
      this.println(6, (Object[])array);
   }

   public void e(String format, Object... args) {
      this.println(6, format, (Object[])args);
   }

   public void e(String msg) {
      this.println(6, (String)msg);
   }

   public void e(String msg, Throwable tr) {
      this.println(6, msg, (Throwable)tr);
   }

   public void log(int logLevel, Object object) {
      this.println(logLevel, object);
   }

   public void log(int logLevel, Object[] array) {
      this.println(logLevel, array);
   }

   public void log(int logLevel, String format, Object... args) {
      this.println(logLevel, format, args);
   }

   public void log(int logLevel, String msg) {
      this.println(logLevel, msg);
   }

   public void log(int logLevel, String msg, Throwable tr) {
      this.println(logLevel, msg, tr);
   }

   public void json(String json) {
      LogConfiguration var2;
      if (3 >= (var2 = this.logConfiguration).logLevel) {
         this.printlnInternal(3, var2.jsonFormatter.format(json));
      }
   }

   public void xml(String xml) {
      LogConfiguration var2;
      if (3 >= (var2 = this.logConfiguration).logLevel) {
         this.printlnInternal(3, var2.xmlFormatter.format(xml));
      }
   }

   void println(int logLevel, String msg) {
      if (logLevel >= this.logConfiguration.logLevel) {
         if (msg == null) {
            msg = "";
         }

         this.printlnInternal(logLevel, msg);
      }
   }

   public static class Builder {
      private int logLevel;
      private String tag;
      private boolean withThread;
      private boolean threadSet;
      private boolean withStackTrace;
      private String stackTraceOrigin;
      private int stackTraceDepth;
      private boolean stackTraceSet;
      private boolean withBorder;
      private boolean borderSet;
      private JsonFormatter jsonFormatter;
      private XmlFormatter xmlFormatter;
      private ThrowableFormatter throwableFormatter;
      private ThreadFormatter threadFormatter;
      private StackTraceFormatter stackTraceFormatter;
      private BorderFormatter borderFormatter;
      private Map<Class<?>, ObjectFormatter<?>> objectFormatters;
      private List<Interceptor> interceptors;
      private Printer printer;

      public Builder() {
         XLog.assertInitialization();
      }

      public Builder logLevel(int logLevel) {
         this.logLevel = logLevel;
         return this;
      }

      public Builder tag(String tag) {
         this.tag = tag;
         return this;
      }

      /** @deprecated */
      @Deprecated
      public Builder t() {
         return this.enableThreadInfo();
      }

      public Builder enableThreadInfo() {
         this.withThread = true;
         this.threadSet = true;
         return this;
      }

      /** @deprecated */
      @Deprecated
      public Builder nt() {
         return this.disableThreadInfo();
      }

      public Builder disableThreadInfo() {
         this.withThread = false;
         this.threadSet = true;
         return this;
      }

      /** @deprecated */
      @Deprecated
      public Builder st(int depth) {
         return this.enableStackTrace(depth);
      }

      public Builder enableStackTrace(int depth) {
         this.withStackTrace = true;
         this.stackTraceDepth = depth;
         this.stackTraceSet = true;
         return this;
      }

      /** @deprecated */
      @Deprecated
      public Builder st(String stackTraceOrigin, int depth) {
         return this.enableStackTrace(stackTraceOrigin, depth);
      }

      public Builder enableStackTrace(String stackTraceOrigin, int depth) {
         this.withStackTrace = true;
         this.stackTraceOrigin = stackTraceOrigin;
         this.stackTraceDepth = depth;
         this.stackTraceSet = true;
         return this;
      }

      /** @deprecated */
      @Deprecated
      public Builder nst() {
         return this.disableStackTrace();
      }

      public Builder disableStackTrace() {
         this.withStackTrace = false;
         this.stackTraceOrigin = null;
         this.stackTraceDepth = 0;
         this.stackTraceSet = true;
         return this;
      }

      /** @deprecated */
      @Deprecated
      public Builder b() {
         return this.enableBorder();
      }

      public Builder enableBorder() {
         this.withBorder = true;
         this.borderSet = true;
         return this;
      }

      /** @deprecated */
      @Deprecated
      public Builder nb() {
         return this.disableBorder();
      }

      public Builder disableBorder() {
         this.withBorder = false;
         this.borderSet = true;
         return this;
      }

      public Builder jsonFormatter(JsonFormatter jsonFormatter) {
         this.jsonFormatter = jsonFormatter;
         return this;
      }

      public Builder xmlFormatter(XmlFormatter xmlFormatter) {
         this.xmlFormatter = xmlFormatter;
         return this;
      }

      public Builder throwableFormatter(ThrowableFormatter throwableFormatter) {
         this.throwableFormatter = throwableFormatter;
         return this;
      }

      public Builder threadFormatter(ThreadFormatter threadFormatter) {
         this.threadFormatter = threadFormatter;
         return this;
      }

      public Builder stackTraceFormatter(StackTraceFormatter stackTraceFormatter) {
         this.stackTraceFormatter = stackTraceFormatter;
         return this;
      }

      public Builder borderFormatter(BorderFormatter borderFormatter) {
         this.borderFormatter = borderFormatter;
         return this;
      }

      public <T> Builder addObjectFormatter(Class<T> objectClass, ObjectFormatter<? super T> objectFormatter) {
         if (this.objectFormatters == null) {
            this.objectFormatters = new HashMap(DefaultsFactory.builtinObjectFormatters());
         }

         this.objectFormatters.put(objectClass, objectFormatter);
         return this;
      }

      public Builder addInterceptor(Interceptor interceptor) {
         if (this.interceptors == null) {
            ArrayList var2;
            var2 = new ArrayList.<init>();
            this.interceptors = var2;
         }

         this.interceptors.add(interceptor);
         return this;
      }

      public Builder printers(Printer... printers) {
         if (printers.length == 0) {
            this.printer = null;
         } else if (printers.length == 1) {
            this.printer = printers[0];
         } else {
            PrinterSet var2;
            var2 = new PrinterSet.<init>(printers);
            this.printer = var2;
         }

         return this;
      }

      public void v(Object object) {
         this.build().v(object);
      }

      public void v(Object[] array) {
         this.build().v(array);
      }

      public void v(String format, Object... args) {
         this.build().v(format, args);
      }

      public void v(String msg) {
         this.build().v(msg);
      }

      public void v(String msg, Throwable tr) {
         this.build().v(msg, tr);
      }

      public void d(Object object) {
         this.build().d(object);
      }

      public void d(Object[] array) {
         this.build().d(array);
      }

      public void d(String format, Object... args) {
         this.build().d(format, args);
      }

      public void d(String msg) {
         this.build().d(msg);
      }

      public void d(String msg, Throwable tr) {
         this.build().d(msg, tr);
      }

      public void i(Object object) {
         this.build().i(object);
      }

      public void i(Object[] array) {
         this.build().i(array);
      }

      public void i(String format, Object... args) {
         this.build().i(format, args);
      }

      public void i(String msg) {
         this.build().i(msg);
      }

      public void i(String msg, Throwable tr) {
         this.build().i(msg, tr);
      }

      public void w(Object object) {
         this.build().w(object);
      }

      public void w(Object[] array) {
         this.build().w(array);
      }

      public void w(String format, Object... args) {
         this.build().w(format, args);
      }

      public void w(String msg) {
         this.build().w(msg);
      }

      public void w(String msg, Throwable tr) {
         this.build().w(msg, tr);
      }

      public void e(Object object) {
         this.build().e(object);
      }

      public void e(Object[] array) {
         this.build().e(array);
      }

      public void e(String format, Object... args) {
         this.build().e(format, args);
      }

      public void e(String msg) {
         this.build().e(msg);
      }

      public void e(String msg, Throwable tr) {
         this.build().e(msg, tr);
      }

      public void log(int logLevel, Object object) {
         this.build().log(logLevel, object);
      }

      public void log(int logLevel, Object[] array) {
         this.build().log(logLevel, array);
      }

      public void log(int logLevel, String format, Object... args) {
         this.build().log(logLevel, format, args);
      }

      public void log(int logLevel, String msg) {
         this.build().log(logLevel, msg);
      }

      public void log(int logLevel, String msg, Throwable tr) {
         this.build().log(logLevel, msg, tr);
      }

      public void json(String json) {
         this.build().json(json);
      }

      public void xml(String xml) {
         this.build().xml(xml);
      }

      public Logger build() {
         return new Logger(this);
      }
   }
}
